require 'active_support/configurable'

module SecureShare

  def self.configure(&block)
    yield @config ||= SecureShare::Configuration.new
    config.ensure_configured!
  end

  def self.config
    @config
  end
  
  class Configuration
    include ActiveSupport::Configurable
    config_accessor :url do
      'https://api.secureshare.com.au'
    end

    ATTRS = [:api_key, :api_secret, :org_name]

    config_accessor *ATTRS

    def ensure_configured!
      ATTRS.each do |attr|
        raise "SecureShare config option missing: #{attr}" unless send(attr)
      end
    end
  end
end
